<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="de">
<context>
    <name>Application</name>
    <message>
        <location filename="../reader/Application.cpp" line="39"/>
        <source>Document Viewer</source>
        <translation>Dokumentbetrachter</translation>
    </message>
    <message>
        <location filename="../reader/Application.cpp" line="40"/>
        <source>Document Viewer is a tool for reading document files, supporting PDF, DJVU, DOCX etc.</source>
        <translation>Dokumentbetrachter ist ein Werkzeug zum Lesen von Dokumentdateien, das PDF, DJVU, DOCX, usw. unterstützt.</translation>
    </message>
</context>
<context>
    <name>AttrScrollWidget</name>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="46"/>
        <source>Location</source>
        <translation>Ort</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="47"/>
        <source>Subject</source>
        <translation>Betreff</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="48"/>
        <source>Author</source>
        <translation>Autor</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="49"/>
        <source>Keywords</source>
        <translation>Schlagwörter</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="50"/>
        <source>Producer</source>
        <translation>Produzent</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="51"/>
        <source>Creator</source>
        <translation>Ersteller</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="52"/>
        <source>Time created</source>
        <translation>Erstellungszeit</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="53"/>
        <source>Time modified</source>
        <translation>Änderungszeit</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="54"/>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="55"/>
        <source>Pages</source>
        <translation>Seiten</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="56"/>
        <source>Optimized</source>
        <translation>Optimiert</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="57"/>
        <source>Security</source>
        <translation>Sicherheit</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="59"/>
        <source>Page size</source>
        <translation>Seitengröße</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="60"/>
        <source>File size</source>
        <translation>Dateigröße</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="65"/>
        <source>Basic info</source>
        <translation>Basisinformationen</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="85"/>
        <source>Unknown</source>
        <translation>Unbekannt</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="127"/>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="127"/>
        <source>No</source>
        <translation>Nein</translation>
    </message>
</context>
<context>
    <name>BookMarkWidget</name>
    <message>
        <location filename="../reader/sidebar/BookMarkWidget.cpp" line="64"/>
        <source>Add bookmark</source>
        <translation>Lesezeichen hinzufügen</translation>
    </message>
    <message>
        <location filename="../reader/sidebar/BookMarkWidget.cpp" line="220"/>
        <source>Are you sure you want to delete all bookmarks?</source>
        <translation>Sind Sie sicher, dass Sie alle Lesezeichen löschen möchten?</translation>
    </message>
</context>
<context>
    <name>BrowserMenu</name>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="39"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="52"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="56"/>
        <source>Copy</source>
        <translation>Kopieren</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="43"/>
        <source>Remove annotation</source>
        <translation>Anmerkung entfernen</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="44"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="73"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="134"/>
        <source>Add annotation</source>
        <translation>Anmerkung hinzufügen</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="47"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="77"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="85"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="129"/>
        <source>Remove bookmark</source>
        <translation>Lesezeichen entfernen</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="49"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="79"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="87"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="131"/>
        <source>Add bookmark</source>
        <translation>Lesezeichen hinzufügen</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="60"/>
        <source>Highlight</source>
        <translation>Hervorheben</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="69"/>
        <source>Remove highlight</source>
        <translation>Hervorhebung entfernen</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="81"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="124"/>
        <source>Search</source>
        <translation>Suchen</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="92"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="140"/>
        <source>Exit fullscreen</source>
        <translation>Vollbild beenden</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="94"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="142"/>
        <source>Fullscreen</source>
        <translation>Vollbild</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="97"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="145"/>
        <source>Slide show</source>
        <translation>Diaschau</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="100"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="148"/>
        <source>First page</source>
        <translation>Erste Seite</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="101"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="149"/>
        <source>Previous page</source>
        <translation>Vorherige Seite</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="107"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="155"/>
        <source>Next page</source>
        <translation>Nächste Seite</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="108"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="156"/>
        <source>Last page</source>
        <translation>Letzte Seite</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="116"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="164"/>
        <source>Rotate left</source>
        <translation>Nach links drehen</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="117"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="165"/>
        <source>Rotate right</source>
        <translation>Nach rechts drehen</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="120"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="168"/>
        <source>Print</source>
        <translation>Drucken</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="121"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="169"/>
        <source>Document info</source>
        <translation>Dokumentinformationen</translation>
    </message>
</context>
<context>
    <name>Central</name>
    <message>
        <location filename="../reader/uiframe/Central.cpp" line="147"/>
        <source>Documents</source>
        <translation>Dokumente</translation>
    </message>
</context>
<context>
    <name>CentralDocPage</name>
    <message>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="166"/>
        <source>The format is not supported</source>
        <translation>Das Format wird nicht unterstützt</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="208"/>
        <source>Open failed</source>
        <translation>Öffnen fehlgeschlagen</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="210"/>
        <source>Please check if the file is damaged</source>
        <translation>Bitte prüfen Sie, ob die Datei beschädigt ist</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="212"/>
        <source>Conversion failed, please check if the file is damaged</source>
        <translation>Konvertierung fehlgeschlagen, bitte prüfen Sie, ob die Datei beschädigt ist</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="420"/>
        <source>Save failed</source>
        <translation>Speichern fehlgeschlagen</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="426"/>
        <source>Saved successfully</source>
        <translation>Erfolgreich gespeichert</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="444"/>
        <source>Save as</source>
        <translation>Speichern unter</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="453"/>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="463"/>
        <source>Invalid file name</source>
        <translation>Ungültiger Dateiname</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="455"/>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="465"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>CentralNavPage</name>
    <message>
        <location filename="../reader/uiframe/CentralNavPage.cpp" line="35"/>
        <source>Drag documents here</source>
        <translation>Dokumente hierher ziehen</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralNavPage.cpp" line="41"/>
        <source>Format supported: %1</source>
        <translation>Format unterstützt: %1</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralNavPage.cpp" line="47"/>
        <source>Select File</source>
        <translation>Datei auswählen</translation>
    </message>
</context>
<context>
    <name>DocSheet</name>
    <message>
        <location filename="../reader/uiframe/DocSheet.cpp" line="332"/>
        <location filename="../reader/uiframe/DocSheet.cpp" line="360"/>
        <source>The bookmark has been removed</source>
        <translation>Das Lesezeichen wurde entfernt</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/DocSheet.cpp" line="533"/>
        <location filename="../reader/uiframe/DocSheet.cpp" line="548"/>
        <source>Please select the text</source>
        <translation>Bitte wählen Sie den Text aus</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/DocSheet.cpp" line="598"/>
        <location filename="../reader/uiframe/DocSheet.cpp" line="607"/>
        <source>The annotation has been removed</source>
        <translation>Die Anmerkung wurde entfernt</translation>
    </message>
</context>
<context>
    <name>EncryptionPage</name>
    <message>
        <location filename="../reader/widgets/EncryptionPage.cpp" line="50"/>
        <source>Encrypted file, please enter the password</source>
        <translation>Verschlüsselte Datei, bitte geben Sie das Passwort ein</translation>
    </message>
    <message>
        <location filename="../reader/widgets/EncryptionPage.cpp" line="56"/>
        <source>Password</source>
        <translation>Passwort</translation>
    </message>
    <message>
        <location filename="../reader/widgets/EncryptionPage.cpp" line="61"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../reader/widgets/EncryptionPage.cpp" line="105"/>
        <source>Wrong password</source>
        <translation>Falsches Passwort</translation>
    </message>
</context>
<context>
    <name>FindWidget</name>
    <message>
        <location filename="../reader/widgets/FindWidget.cpp" line="127"/>
        <source>Previous</source>
        <translation>Vorherige</translation>
    </message>
    <message>
        <location filename="../reader/widgets/FindWidget.cpp" line="135"/>
        <source>Next</source>
        <translation>Nächste</translation>
    </message>
</context>
<context>
    <name>HandleMenu</name>
    <message>
        <location filename="../reader/widgets/HandleMenu.cpp" line="35"/>
        <source>Select Text</source>
        <translation>Text auswählen</translation>
    </message>
    <message>
        <location filename="../reader/widgets/HandleMenu.cpp" line="43"/>
        <source>Hand Tool</source>
        <translation>Handwerkzeug</translation>
    </message>
</context>
<context>
    <name>NotesWidget</name>
    <message>
        <location filename="../reader/sidebar/NotesWidget.cpp" line="67"/>
        <source>Add annotation</source>
        <translation>Anmerkung hinzufügen</translation>
    </message>
    <message>
        <location filename="../reader/sidebar/NotesWidget.cpp" line="189"/>
        <source>Are you sure you want to delete all annotations?</source>
        <translation>Sind Sie sicher, dass Sie alle Lesezeichen löschen möchten?</translation>
    </message>
</context>
<context>
    <name>PagingWidget</name>
    <message>
        <location filename="../reader/widgets/PagingWidget.cpp" line="212"/>
        <source>Invalid page number</source>
        <translation>Ungültige Seitennummer</translation>
    </message>
</context>
<context>
    <name>ProgressDialog</name>
    <message>
        <location filename="../reader/widgets/ProgressDialog.cpp" line="18"/>
        <source>Converting</source>
        <translation>Wird konvertiert</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../reader/app/DBusObject.cpp" line="103"/>
        <source>Document not saved</source>
        <translation>Dokument nicht gespeichert</translation>
    </message>
</context>
<context>
    <name>SaveDialog</name>
    <message>
        <location filename="../reader/widgets/SaveDialog.cpp" line="35"/>
        <source>Save the changes to &quot;%1&quot;?</source>
        <translation>Änderungen zu „%1“ speichern?</translation>
    </message>
    <message>
        <location filename="../reader/widgets/SaveDialog.cpp" line="37"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../reader/widgets/SaveDialog.cpp" line="37"/>
        <source>Discard</source>
        <comment>button</comment>
        <translation>Verwerfen</translation>
    </message>
    <message>
        <location filename="../reader/widgets/SaveDialog.cpp" line="38"/>
        <source>Save</source>
        <comment>button</comment>
        <translation>Speichern</translation>
    </message>
    <message>
        <location filename="../reader/widgets/SaveDialog.cpp" line="49"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../reader/widgets/SaveDialog.cpp" line="50"/>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
</context>
<context>
    <name>ScaleMenu</name>
    <message>
        <location filename="../reader/widgets/ScaleMenu.cpp" line="35"/>
        <source>Two-Page View</source>
        <translation>Zwei-Seiten-Ansicht</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ScaleMenu.cpp" line="36"/>
        <source>1:1 size</source>
        <translation>Größe 1:1</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ScaleMenu.cpp" line="37"/>
        <source>Fit Page</source>
        <translation>Seite anpassen</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ScaleMenu.cpp" line="38"/>
        <source>Fit Height</source>
        <translation>Höhe anpassen</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ScaleMenu.cpp" line="39"/>
        <source>Fit Width</source>
        <translation>Breite anpassen</translation>
    </message>
</context>
<context>
    <name>SearchResWidget</name>
    <message>
        <location filename="../reader/sidebar/SearchResWidget.cpp" line="60"/>
        <source>No search results</source>
        <translation>Keine Suchergebnisse</translation>
    </message>
    <message>
        <location filename="../reader/sidebar/SearchResWidget.cpp" line="111"/>
        <source>%1 items found</source>
        <translation> %1 Elemente gefunden</translation>
    </message>
</context>
<context>
    <name>SecurityDialog</name>
    <message>
        <location filename="../reader/widgets/SecurityDialog.cpp" line="72"/>
        <source>This document is trying to connect to:</source>
        <translation>Dieses Dokument versucht, eine Verbindung herzustellen mit:</translation>
    </message>
    <message>
        <location filename="../reader/widgets/SecurityDialog.cpp" line="73"/>
        <source>If you trust the website, click Allow, otherwise click Block.</source>
        <translation>Falls Sie dieser Website vertrauen, klicken Sie &apos;Erlauben&apos;, falls nicht &apos;Blockieren&apos;.</translation>
    </message>
    <message>
        <location filename="../reader/widgets/SecurityDialog.cpp" line="76"/>
        <source>Block</source>
        <comment>button</comment>
        <translation>Blockieren</translation>
    </message>
    <message>
        <location filename="../reader/widgets/SecurityDialog.cpp" line="77"/>
        <source>Allow</source>
        <comment>button</comment>
        <translation>Erlauben</translation>
    </message>
</context>
<context>
    <name>SheetSidebar</name>
    <message>
        <location filename="../reader/sidebar/SheetSidebar.cpp" line="84"/>
        <source>Thumbnails</source>
        <translation>Vorschaubilder</translation>
    </message>
    <message>
        <location filename="../reader/sidebar/SheetSidebar.cpp" line="99"/>
        <source>Catalog</source>
        <translation>Katalog</translation>
    </message>
    <message>
        <location filename="../reader/sidebar/SheetSidebar.cpp" line="112"/>
        <source>Bookmarks</source>
        <translation>Lesezeichen</translation>
    </message>
    <message>
        <location filename="../reader/sidebar/SheetSidebar.cpp" line="127"/>
        <source>Annotations</source>
        <translation>Anmerkungen</translation>
    </message>
</context>
<context>
    <name>ShortCutShow</name>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="60"/>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="124"/>
        <source>Exit</source>
        <translation>Beenden</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="100"/>
        <source>Help</source>
        <translation>Hilfe</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="120"/>
        <source>Page up</source>
        <translation>Bild auf</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="121"/>
        <source>Page down</source>
        <translation>Bild ab</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="105"/>
        <source>Open</source>
        <translation>Öffnen</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="118"/>
        <source>Zoom in</source>
        <translation>Hineinzoomen</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="119"/>
        <source>Zoom out</source>
        <translation>Herauszoomen</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="106"/>
        <source>Save as</source>
        <translation>Speichern als</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="107"/>
        <source>Print</source>
        <translation>Drucken</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="108"/>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="112"/>
        <source>Thumbnails</source>
        <translation>Vorschaubilder</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="113"/>
        <source>1:1 size</source>
        <translation>Größe 1:1</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="114"/>
        <source>Fit height</source>
        <translation>Höhe anpassen</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="115"/>
        <source>Fit width</source>
        <translation>Breite anpassen</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="116"/>
        <source>Rotate left</source>
        <translation>Nach links drehen</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="117"/>
        <source>Rotate right</source>
        <translation>Nach rechts drehen</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="122"/>
        <source>Move to the beginning</source>
        <translation>Zum Anfang springen</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="123"/>
        <source>Move to the end</source>
        <translation>Zum Ende springen</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="128"/>
        <source>Select text</source>
        <translation>Text auswählen</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="129"/>
        <source>Hand tool</source>
        <translation>Handwerkzeug</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="130"/>
        <source>Add bookmark</source>
        <translation>Lesezeichen hinzufügen</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="143"/>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="133"/>
        <source>Magnifier</source>
        <translation>Lupe</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="135"/>
        <source>Slide show</source>
        <translation>Diaschau</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="136"/>
        <source>Fullscreen</source>
        <translation>Vollbild</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="140"/>
        <source>Copy</source>
        <translation>Kopieren</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="141"/>
        <source>Cut</source>
        <translation>Ausschneiden</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="142"/>
        <source>Paste</source>
        <translation>Einfügen</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="144"/>
        <source>Undo</source>
        <translation>Rückgängig</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="145"/>
        <source>Select all</source>
        <translation>Alles auswählen</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="101"/>
        <source>Display shortcuts</source>
        <translation>Tastaturkombinationen anzeigen</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="131"/>
        <source>Add annotation</source>
        <translation>Anmerkung hinzufügen</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="132"/>
        <source>Highlight</source>
        <translation>Hervorheben</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="134"/>
        <source>Search</source>
        <translation>Suchen</translation>
    </message>
</context>
<context>
    <name>SideBarImageListView</name>
    <message>
        <location filename="../reader/sidebar/SideBarImageListview.cpp" line="194"/>
        <source>Copy</source>
        <translation>Kopieren</translation>
    </message>
    <message>
        <location filename="../reader/sidebar/SideBarImageListview.cpp" line="199"/>
        <source>Remove annotation</source>
        <translation>Anmerkung entfernen</translation>
    </message>
    <message>
        <location filename="../reader/sidebar/SideBarImageListview.cpp" line="204"/>
        <location filename="../reader/sidebar/SideBarImageListview.cpp" line="223"/>
        <source>Remove all</source>
        <translation>Alle entfernen</translation>
    </message>
    <message>
        <location filename="../reader/sidebar/SideBarImageListview.cpp" line="218"/>
        <source>Remove bookmark</source>
        <translation>Lesezeichen entfernen</translation>
    </message>
</context>
<context>
    <name>SideBarImageViewModel</name>
    <message>
        <location filename="../reader/sidebar/SideBarImageViewModel.cpp" line="135"/>
        <source>Page %1</source>
        <translation>Seite %1</translation>
    </message>
</context>
<context>
    <name>SlidePlayWidget</name>
    <message>
        <location filename="../reader/widgets/SlidePlayWidget.cpp" line="127"/>
        <source>It is the first page</source>
        <translation>Es ist die erste Seite</translation>
    </message>
    <message>
        <location filename="../reader/widgets/SlidePlayWidget.cpp" line="132"/>
        <source>It is the last page</source>
        <translation>Es ist die letzte Seite</translation>
    </message>
</context>
<context>
    <name>TitleMenu</name>
    <message>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="29"/>
        <source>New window</source>
        <translation>Neues Fenster</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="29"/>
        <source>New tab</source>
        <translation>Neuer Tab</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="39"/>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="110"/>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="39"/>
        <source>Save as</source>
        <translation>Speichern als</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="44"/>
        <source>Display in file manager</source>
        <translation>Im Dateimanager anzeigen</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="44"/>
        <source>Magnifer</source>
        <translation>Lupe</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="50"/>
        <source>Tools</source>
        <translation>Werkzeuge</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="54"/>
        <source>Search</source>
        <translation>Suchen</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="54"/>
        <source>Print</source>
        <translation>Drucken</translation>
    </message>
</context>
<context>
    <name>TitleWidget</name>
    <message>
        <location filename="../reader/uiframe/TitleWidget.cpp" line="37"/>
        <source>Thumbnails</source>
        <translation>Vorschaubilder</translation>
    </message>
</context>
<context>
    <name>TransparentTextEdit</name>
    <message>
        <location filename="../reader/widgets/TransparentTextEdit.cpp" line="82"/>
        <source>Input limit reached</source>
        <translation>Eingabelimit erreicht</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../reader/main.cpp" line="40"/>
        <source>Document File Path.</source>
        <translation>Document File Path.</translation>
    </message>
    <message>
        <location filename="../reader/main.cpp" line="41"/>
        <location filename="../reader/main.cpp" line="45"/>
        <source>FilePath</source>
        <translation>FilePath</translation>
    </message>
    <message>
        <location filename="../reader/main.cpp" line="44"/>
        <source>ThumbnailPath Path.</source>
        <translation>ThumbnailPath Path.</translation>
    </message>
    <message>
        <location filename="../reader/main.cpp" line="49"/>
        <source>Generate thumbnail.</source>
        <translation>Vorschaubild generieren.</translation>
    </message>
</context>
</TS>